/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

/**
 * Field displaying a combobox allowing to select one of the values from a given enumerator. 
 */
Ext.define('Ametys.form.widget.EnumeratorCombobox', {
    extend: "Ametys.form.AbstractQueryableComboBox",
	
    getStore: function ()
    {
        return Ext.create('Ext.data.Store', {
            proxy: {
                type: 'ametys',
                role: 'org.ametys.plugins.core.ui.util.ParameterEnumeratorHelper',
                methodName: 'getTypedEntries',
                methodArguments: ['role'],
                reader: {
                    type: 'json',
                    rootProperty: "data"
                }
            },
            autoLoad: true, 
            sorters: [{property: 'title', direction: 'ASC'}],
            listeners: {
                scope: this,
                'beforeload': function(store, operation)
                {
                    // Get the parameters, or create empty object if needed
                    var parameters = operation.getParams() || {};
                    // Add the enumerator role to the parameters
                    params = Ext.apply(parameters, {role: this.getInitialConfig()["enumerator-role"]});
                    // Set the parameters
                    operation.setParams(parameters);
                }
            }
        });
    },
    
    constructor: function (config)
    {
        config = Ext.apply(config, {
            queryMode: 'local'
        });
        
        this.callParent(arguments);
    },
});
